====
Help
====


Frequently Asked Questions
==========================


What does it mean by "Wget-compatible"?
+++++++++++++++++++++++++++++++++++++++

It means that Wpull behaves similarly to Wget, but the internal machinery
that powers Wpull is completely different from Wget.


Wpull is giving an error or not performing correctly.
+++++++++++++++++++++++++++++++++++++++++++++++++++++

If Wpull is not doing what you want, please visit the `issue tracker
<https://github.com/chfoo/wpull/issues>`_ and see if your issue is there.
If not, please inform the developers by creating a new issue. Include
details of your computer including:

* What you want, what you expect, what happened.
* The command or website causes the problem
* Operating system
* Python version
* Wpull version
* A copy and paste of what Wpull prints out


How can I chat or ask a question?
+++++++++++++++++++++++++++++++++

* You can ask questions here: https://answers.launchpad.net/wpull.
* The lead developer is available to chat on IRC: #archiveteam-bs on EFNet.
* Email is also available: chris.foo@gmail.com


